@@ -1,6 +1,6 @@
 """Houses Models"""
 
-from pyrestsdk.type.model._base_entity import BaseEntity
+from pyrestsdk.type.model._entity import Entity
 from pyrestsdk.type.model._option import Option
 from pyrestsdk.type.model._query_option import QueryOption
 from pyrestsdk.type.model._header_option import HeaderOption
@@ -8,9 +8,11 @@ from pyrestsdk.type.model._options_collection import OptionsCollection
 from pyrestsdk.type.model._header_option_collection import HeaderOptionCollection
 from pyrestsdk.type.model._query_option_collection import QueryOptionCollection
 from pyrestsdk.type.model._type_collection import TypeCollection
+from pyrestsdk.type.model._common_base import CommonBase
 
 __all__ = [
-    "BaseEntity",
+    "CommonBase",
+    "Entity",
     "Option",
     "QueryOption",
     "HeaderOption",
